# CycloMonitor Privacy Policy
We care about your privacy. No private information is collected unless it's required for bot functionality. Any data that is stored will **never** be shared with third-parties.  
CycloMonitor stores the following information:
- Guilds*
  - ID*
  - *One* channel*
  - Basin selection*
- Users**
  - Username
  - Discriminator (if applicable)
  - Most recently used command

*Required  
**Only logged in certain conditions

CycloMonitor does not collect any personal information nor require any privileged intents. You should avoid any instance of the bot that uses privileged intents to protect your privacy.  
